def RunFatima(T, diam, particleDensity, params):
    
    import numpy as np
    from FatimaAnalyticalSolution import FatimaAnalyticalSolution
    
    # diam = diameter, measured in microns
    # particleDensity = particle density, measured in g/cm3
    # G (from params) measured in mg/min
    
    diam_meters = np.multiply(diam, 10**-6)
    particleDensity_kgperm3 = particleDensity*(10**3)
    particleMass = np.pi*np.multiply(np.divide(np.power(diam_meters,3), 6), particleDensity_kgperm3)
    
    # Convert G from ppm to kg/s
    G = np.multiply(params['G'], particleMass)/(60*(10**3))
    params['G'] = G
    
    tSpan_15s = np.arange(0, T+1, step=15)
    Cz0 = np.array([0])
    y_analytical = FatimaAnalyticalSolution(tSpan_15s, Cz0, params)
    y_analytical_conv = np.divide(y_analytical, particleMass) # in #/m3

    return y_analytical_conv